createSample_states: Create sample state matrix

View source: R/simulations.R

createSample_statesR Documentation

Create sample state matrix

Description

Function that creates a matrix with the probability of each tip of the phylogenetic tree be associate to a deme. Each row of the matrix should sum to 1.

Usage

createSample_states(state_info)

Arguments

state_info

dataframe containing the information of tip names and state. State is a character associating each tip to a deme of the structured coalescent model. #'

Value

matrix in which each column represent a state (or deme name) and each row is a name for the tip of the phylogenetic tree. Each row should sum to 1.

Examples

tip_data <- create_tip_names()
sampleStates <- createSample_states(tip_data)

thednainus/sarscov2simulations documentation built on Feb. 9, 2023, 2:12 p.m.