create_tip_names: Create tip names

View source: R/simulations.R

create_tip_namesR Documentation

Create tip names

Description

This function will create names for terminal branches (tip) in the phylogenetic tree. It will also associate each tip to a deme from the structured coalescent model.

Usage

create_tip_names(region_n = 100, exog_n = 50)

Arguments

region_n

numeric which is defined as the number of tips for the region data. Region data are data for the region of interest. Default is set to 100.

exog_n

numeric which is defined as the number of tips for exogenous data. Exogenous data are data for other regions that are not the region of interest. Default is set to 50.

Value

dataframe for tip names and states associated to each tip name

Examples

tip_data <- create_tip_names()

thednainus/sarscov2simulations documentation built on Feb. 9, 2023, 2:12 p.m.