rename_tips: Rename tip names

View source: R/simulations.R

rename_tipsR Documentation

Rename tip names

Description

Function to rename tip names to include information of sample times

Usage

rename_tips(tip_name, tip_time)

Arguments

tip_name

tip name after spliting the name into two: first part contains the tip name, second part contains the state name. For example: if tip name is "Seq1_exog", the splitted form will be "Seq1" "exog".

tip_time

time for correspondent tip name

Value

new tip name

Examples

TO DO

thednainus/sarscov2simulations documentation built on Feb. 9, 2023, 2:12 p.m.