| sampler | R Documentation |
Funtion that will sample parameter values from a uniform distribution based on latin hypercube sampling.
sampler(n = 100)
n |
numeric for the number of samples. Default is set to 100. |
This function will sample from a uniform distribution parameter values for b, initS (initial size of susceptibles), import (importation rate), st (start time) and E (initial size of exposed individuals). Boundaries for each parameter: b: min = 15, max = 25 initS: min = 1e4, max = 1e6 import: min = 1, max = 10 st: min = 2020.10, max = 2020.15 E: min = 1, max = 30
dataframe for parameters sampled.
#the example below will sample 100 parameter values for each b, initS, import, and st from a uniform ditribution parameters <- sampler()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.