| createSample_states | R Documentation |
Function that creates a matrix with the probability of each tip of the phylogenetic tree be associate to a deme. Each row of the matrix should sum to 1.
createSample_states(state_info)
state_info |
dataframe containing the information of tip names and state. State is a character associating each tip to a deme of the structured coalescent model. #' |
matrix in which each column represent a state (or deme name) and each row is a name for the tip of the phylogenetic tree. Each row should sum to 1.
tip_data <- create_tip_names() sampleStates <- createSample_states(tip_data)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.