| create_tip_names | R Documentation |
This function will create names for terminal branches (tip) in the phylogenetic tree. It will also associate each tip to a deme from the structured coalescent model.
create_tip_names(region_n = 100, exog_n = 50)
region_n |
numeric which is defined as the number of tips for the region data. Region data are data for the region of interest. Default is set to 100. |
exog_n |
numeric which is defined as the number of tips for exogenous data. Exogenous data are data for other regions that are not the region of interest. Default is set to 50. |
dataframe for tip names and states associated to each tip name
tip_data <- create_tip_names()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.