| rename_tips | R Documentation |
Function to rename tip names to include information of sample times
rename_tips(tip_name, tip_time)
tip_name |
tip name after spliting the name into two: first part contains the tip name, second part contains the state name. For example: if tip name is "Seq1_exog", the splitted form will be "Seq1" "exog". |
tip_time |
time for correspondent tip name |
new tip name
TO DO
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.